@@ -18,7 +18,7 @@
 #include "umldoc.h"
 #include "umlobjectlist.h"
 
-#include <klocale.h>
+#include <KLocalizedString>
 
 #include <QHBoxLayout>
 #include <QGroupBox>
@@ -94,9 +94,10 @@ void PackageContentsPage::fillListBox()
     m_contentLW->clear();
     UMLObjectList contents = m_package->containedObjects();
     UMLObjectListIt objList_it(contents);
-    UMLObject* umlo = NULL;
+    UMLObject* umlo = 0;
     while (objList_it.hasNext()) {
         umlo = objList_it.next();
+        uIgnoreZeroPointer(umlo);
         m_contentLW->addItem(umlo->name());
     }
 }
@@ -136,4 +137,3 @@ void PackageContentsPage::slotMenuSelection(QAction* action)
     }
 }
 
-#include "packagecontentspage.moc"
