@@ -218,10 +218,10 @@ Uml::ID::Type UMLWidget::localID() const
 UMLWidget* UMLWidget::widgetWithID(Uml::ID::Type id)
 {
     if (id == m_nLocalID ||
-        (m_umlObject != NULL && id == m_umlObject->id()) ||
+        (m_umlObject != 0 && id == m_umlObject->id()) ||
         id == m_nId)
         return this;
-    return NULL;
+    return 0;
 }
 
 /**
@@ -982,9 +982,9 @@ void UMLWidget::setFillColorCmd(const QColor &color)
  */
 bool UMLWidget::activate(IDChangeLog* /*ChangeLog  = 0 */)
 {
-    if (widgetHasUMLObject(baseType()) && m_umlObject == NULL) {
+    if (widgetHasUMLObject(baseType()) && m_umlObject == 0) {
         m_umlObject = m_doc->findObjectById(m_nId);
-        if (m_umlObject == NULL) {
+        if (m_umlObject == 0) {
             uError() << "cannot find UMLObject with id=" << Uml::ID::toString(m_nId);
             return false;
         }
@@ -1819,10 +1819,13 @@ void UMLWidget::saveToXMI(QDomDocument & qDoc, QDomElement & qElement)
     */
     WidgetBase::saveToXMI(qDoc, qElement);
     qElement.setAttribute(QLatin1String("xmi.id"), Uml::ID::toString(id()));
-    qElement.setAttribute(QLatin1String("x"), QString::number(x()));
-    qElement.setAttribute(QLatin1String("y"), QString::number(y()));
-    qElement.setAttribute(QLatin1String("width"), QString::number(width()));
-    qElement.setAttribute(QLatin1String("height"), QString::number(height()));
+
+    qreal dpiScale = UMLApp::app()->document()->dpiScale();
+    qElement.setAttribute(QLatin1String("x"), QString::number(x() / dpiScale));
+    qElement.setAttribute(QLatin1String("y"), QString::number(y() / dpiScale));
+    qElement.setAttribute(QLatin1String("width"), QString::number(width() / dpiScale));
+    qElement.setAttribute(QLatin1String("height"), QString::number(height() / dpiScale));
+
     qElement.setAttribute(QLatin1String("isinstance"), m_isInstance);
     if (!m_instanceName.isEmpty())
         qElement.setAttribute(QLatin1String("instancename"), m_instanceName);
@@ -1844,9 +1847,11 @@ bool UMLWidget::loadFromXMI(QDomElement & qElement)
     QString y = qElement.attribute(QLatin1String("y"), QLatin1String("0"));
     QString h = qElement.attribute(QLatin1String("height"), QLatin1String("0"));
     QString w = qElement.attribute(QLatin1String("width"), QLatin1String("0"));
-    setSize(toDoubleFromAnyLocale(w), toDoubleFromAnyLocale(h));
-    setX(toDoubleFromAnyLocale(x));
-    setY(toDoubleFromAnyLocale(y));
+    qreal dpiScale = UMLApp::app()->document()->dpiScale();
+    setSize(toDoubleFromAnyLocale(w) * dpiScale,
+            toDoubleFromAnyLocale(h) * dpiScale);
+    setX(toDoubleFromAnyLocale(x) * dpiScale);
+    setY(toDoubleFromAnyLocale(y) * dpiScale);
 
     QString isinstance = qElement.attribute(QLatin1String("isinstance"), QLatin1String("0"));
     m_isInstance = (bool)isinstance.toInt();
